@@ -1,15 +1,8 @@
-#Standard Library
-import time
-import logging
-
-#Installed
-import requests
-
 #Local
 from ._session_types import CWPSession
 
 class CWPSessionManager:
-    def __init__(self, tenant_name: str, api_url: str, logger: object, uname='', passwd='', api_token=''):
+    def __init__(self, tenant_name: str, api_url: str, uname: str, passwd: str, verify:bool, project_flag:bool, logger: object):
         """
         Initializes a Prisma Cloud API Session Manager.
 
@@ -24,14 +17,16 @@ class CWPSessionManager:
         self.tenant = tenant_name
         self.uname = uname
         self.passwd = passwd
-        self.api_token = api_token
         self.api_url = api_url
 
+        self.verify = verify
+        self.project_flag = project_flag
+
         self.cwp_session = {}        
 
 
 #==============================================================================
     def create_cwp_session(self):
-        session = CWPSession(self.tenant, self.api_url, self.uname, self.passwd, self.logger)
+        session = CWPSession(self.tenant, self.api_url, self.uname, self.passwd, self.verify, self.project_flag, self.logger)
         self.cwp_session = session
         return session
